@@ -5,4 +5,4 @@ from SQcircuit.elements import *
 from SQcircuit.circuit import *
 from SQcircuit.sweep import *
 from SQcircuit.storage import *
-import SQcircuit.physParam as units
+from SQcircuit.units import *
